OiRA

Help

1. Preparation
2. Involve
3. Identification + Evaluation
4. Action Plan
5. Report
6. Status 0%

# Tailor the risk assessment to your organisation

In order to tailor the risk assessment to your organisation you may be asked to:

- select or skip situation(s) relevant or not to your business activity and tick the box(es) if appropriate
- list multiple business units, or branches, or stores, etc. These related risks will be repeated for each name you have entered.

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search

- Loading Risk Assessments…